@@ -26,9 +26,15 @@ typedef struct
 	gint num_retries;    /* Number of Retries */
 	gchar *http_proxy; /* HTTP Proxy */
 	gint http_proxy_port; /* HTTP Proxy Port */
+	gchar *proxy_user;	/*Proxy user*/
+	gchar *proxy_password; /*Proxy password*/
+	gboolean proxy_uses_auth; /*Proxy requires password*/
 	gchar *gnome_http_proxy; /* GNOME HTTP Proxy */
 	gint gnome_http_proxy_port; /* GNOME HTTP Proxy Port */
-	gboolean gnome_use_proxy;
+	gchar *gnome_proxy_user;	/*GNOME Proxy user*/
+	gchar *gnome_proxy_password; /*GNOME Proxy password*/
+	gboolean gnome_use_proxy;    
+	gboolean gnome_proxy_uses_auth; /*GNOME Proxy requires password*/
 	gchar *network_mode;
 	gboolean resume_at_start;
 	gboolean open_after_dl; /* Open the file after Download */
@@ -44,6 +50,7 @@ typedef struct
 	gboolean view_rem_time;
 	gboolean view_down_speed;
 	gboolean view_toolbar;
+	gboolean view_statusbar;
 	gboolean view_file_type;
 	gboolean docked;
 	gboolean limit_speed;
@@ -81,12 +88,12 @@ typedef struct
     gboolean use_proxy;         /* Used to use proxy */
     gboolean use_auto_dl;       /* Used to use auto download */
     gchar *line;                /* Used to process the wget output */
-    guint32 total_size;         /* Total file size in bytes */
+    guint64 total_size;         /* Total file size in bytes */
     guint32 total_time;         /* Total time spent in seconds */
     time_t session_start_time;  /* Time at start of this download session */
-    guint32 session_start_size; /* Size at start of this download session */
+    guint64 session_start_size; /* Size at start of this download session */
     guint32 session_elapsed;    /* Time spent in seconds on this session */
-    guint32 cur_size;           /* Current downloaded file size */
+    guint64 cur_size;           /* Current downloaded file size */
     DlState state;              /* State of the download */
     GtkTreeIter file_list;       /* GtkTreeIter where this file is inserted */
     guint id;                   /* File data id */
@@ -96,7 +103,7 @@ typedef struct
 	gboolean multimedia;	/* Only download multimedia files in recursive mode */
 	gboolean mirror;		/* Mirror the site in recursive mode */
 	gchar *state_str;
-    
+   gchar *icon_name; 
 } GwgetData;
 
 
@@ -110,13 +117,14 @@ void gwget_data_set_filename(GwgetData* gwgetdata,gchar *str);
 void gwget_data_start_download(GwgetData *gwgetdata);
 void gwget_data_set_state (GwgetData *gwgetdata, DlState state);
 void gwget_data_update_statistics (GwgetData *gwgetdata);
-void gwget_data_set_total_size (GwgetData *gwgetdata,guint32 total_size);
+void gwget_data_set_total_size (GwgetData *gwgetdata,guint64 total_size);
 GwgetData* gwget_data_get_selected(void);
 void gwget_data_free(gpointer data);
 void gwget_data_stop_download(GwgetData *data);
 void gwget_data_set_filename_from_url(GwgetData *gwgetdata, gchar *url);
 void gwget_data_add_download(GwgetData *gwgetdata);
 void gwget_data_exec(GwgetData *gwgetdata);
+void gwget_data_set_menus (GwgetData *gwgetdata);
 
 void gwget_init_pref(Preferences *pref);
 
