@@ -20,7 +20,8 @@
 #define _UTILS_H
 
 
-gint run_dialog(gchar *title, gchar *msg);
+gint run_dialog(gchar *title, gchar *message, gchar *action_message);
+void run_dialog_error(gchar *title, gchar *msg);
 gint run_dialog_information(gchar *title, gchar *msg);
 gboolean check_url_already_exists(gchar *checkurl);
 gboolean check_server_already_exists(gchar *checkurl);
