@@ -22,7 +22,10 @@
 #include <libgnome/gnome-url.h>
 #include <libgnome/gnome-program.h>
 #include <libgnome/gnome-init.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <gnome-vfs-module-2.0/libgnomevfs/gnome-vfs-mime.h>
+
 #include "main_window.h"
 #include "main_window_cb.h"
 #include "new_window.h"
@@ -30,6 +33,8 @@
 #include "utils.h"
 #include "systray.h"
 
+static void inform_limit_speed_change(void);
+
 void 
 on_stop_button_clicked (GtkWidget *widget, gpointer data) 
 {
@@ -49,32 +54,34 @@ on_treeview1_button_press_event(GtkWidget *widget, GdkEventButton *event,gpointe
 	GdkEventButton *event_button;
 	GtkTreeSelection *select;
 	GtkTreeIter iter;
-    GtkTreeModel *model;
+	GtkTreeModel *model;
 	GwgetData *gwgetdata;
 	gchar *uri;
 	GError *err = NULL; 
 	
 	treev=glade_xml_get_widget(xml,"treeview1");
 	select=gtk_tree_view_get_selection(GTK_TREE_VIEW(treev));
-		
+
+	/* Right click - Show popup menu */
 	if (event->type == GDK_BUTTON_PRESS) {
 		event_button = (GdkEventButton *) event;
 		if (event->button==3 && gtk_tree_selection_get_selected (select, &model, &iter)) {
-			gwgetdata=gwget_data_get_selected();
-			if (gwget_data_run(gwgetdata)) {
-				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_download"),TRUE);
-				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_download"),FALSE);
-				gtk_widget_set_sensitive(glade_xml_get_widget(xml,"cancel_download"),TRUE);
-			} else {
-				if (gwgetdata->state==DL_COMPLETED) {
-					gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_download"),FALSE);
-					gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_download"),FALSE);
-					gtk_widget_set_sensitive(glade_xml_get_widget(xml,"cancel_download"),FALSE);
-				} else {
-					gtk_widget_set_sensitive(glade_xml_get_widget(xml,"continue_download"),TRUE);
-					gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_download"),FALSE);
-				}
+
+			/* Select right-clicked line */
+			GtkTreeSelection *selection;
+			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treev));
+			GtkTreePath *path;
+			if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treev),
+                                             (gint) event->x, 
+                                             (gint) event->y,
+                                             &path, NULL, NULL, NULL))
+			{
+				gtk_tree_selection_unselect_all(selection);
+				gtk_tree_selection_select_path(selection, path);
+				gtk_tree_path_free(path);
 			}
+
+			gwget_data_set_menus(gwget_data_get_selected());
 			popup=glade_xml_get_widget(xml,"popup1");
 			gtk_menu_popup (GTK_MENU(popup), NULL, NULL, NULL, NULL, 
 							event_button->button, event_button->time);
@@ -91,12 +98,16 @@ on_treeview1_button_press_event(GtkWidget *widget, GdkEventButton *event,gpointe
 			gwgetdata=gwget_data_get_selected();
 			/* If the download is in error state, show the error message in a dialog */
 			if (gwgetdata->error) {
-				run_dialog(_("Error in download"),gwgetdata->error_msg);
+				run_dialog_error(_("Error in download"),gwgetdata->error_msg);
 			} else {
-				uri = gnome_vfs_make_uri_from_input_with_dirs (gwgetdata->local_filename,
+				if (gwgetdata->recursive) {
+					uri = gnome_vfs_make_uri_from_input(gwgetdata->dir);
+				} else {
+					uri = gnome_vfs_make_uri_from_input_with_dirs (gwgetdata->local_filename,
                                                  GNOME_VFS_MAKE_URI_DIR_CURRENT);
+				}
 				if (!gnome_url_show (uri, &err)) {
-					run_dialog(_("Error opening file"),_("Couldn't open the file"));
+					run_dialog_error(_("Error opening file"),_("Couldn't open the file"));
 					return FALSE;
 				}
 				return TRUE;
@@ -160,46 +171,32 @@ on_quit1_activate(GtkWidget *widget, gpointer data)
 void 
 on_about1_activate(GtkWidget *widget, gpointer data)
 {
-	static GtkWidget *about = NULL;
 	GdkPixbuf *pixbuf = NULL;
 	gchar *logo_file;
-	gchar *copy_text = "Copyright © 2004 David Sedeño Fernández";
-	gchar *about_text = _("Download Manager for GNOME.");
-	gchar *authors[] = { 
+
+	static const gchar *authors[] = { 
 			"David Sedeño Fernández <david@alderia.com>",
 			"Julien Cegarra <julienc@psychologie-fr.org>",
 			NULL
 	};
-
-	gchar *translator_credits = _("translator-credits");
-
-	if (about != NULL ) 
-	{
-		gdk_window_show (about->window);
-		gdk_window_raise (about->window);
-		return;
-	}
-
+		
 	logo_file=g_strdup_printf("%s/%s",DATADIR,"gwget-large.png");
 	pixbuf = gdk_pixbuf_new_from_file (logo_file, NULL);
+	g_free (logo_file);
 
-	about = gnome_about_new (_("Gwget"), VERSION,
-							copy_text,
-							about_text,
-							(const char **)authors,
-							(const char **)NULL,
-							(const char *)translator_credits,
-							pixbuf);
+	gtk_show_about_dialog (NULL,
+			       "name", _("Gwget"), 
+			       "version", VERSION,
+			       "copyright", "Copyright © 2004 David Sedeño Fernández",
+			       "comments", _("Download Manager for GNOME."),
+			       "authors", authors,
+			       "translator-credits", _("translator-credits"),
+			       "logo", pixbuf,
+			       NULL);
 
 	if (pixbuf != NULL) {
 		g_object_unref (pixbuf);
 	}
-	
-	g_signal_connect (G_OBJECT (about), "destroy", 
-						G_CALLBACK (gtk_widget_destroyed), &about);
-	                                                                                                                             
-	gtk_widget_show (about);
-
 }
 
 
@@ -217,19 +214,19 @@ new_download(GwgetData* gwgetdata)
 	GtkIconTheme *theme;
 	GtkIconInfo *icon_info;
 	GdkPixbuf *pixbuf;
-	char *mime, *icon_name, *size;
+	char *mime, *size;
 	int width = 16, height = 16;
 	gdouble perc;
 	
 	gtk_list_store_append (GTK_LIST_STORE(model), &iter); 
-	size = g_strdup_printf ("%d kB", (gwgetdata->cur_size + 512) / 1024);
+	size = g_strdup_printf ("%d kB", (guint32)(gwgetdata->cur_size + 512) / 1024);
 	gtk_list_store_set (GTK_LIST_STORE(model), &iter,URL_COLUMN,gwgetdata->url,
 						CURRENTSIZE_COLUMN, size, 
 						FILENAME_COLUMN, gwgetdata->filename,
 	    				-1);
 	
 	
-	size = g_strdup_printf ("%d kB", (gwgetdata->total_size + 512) / 1024);
+	size = g_strdup_printf ("%d kB", (guint32)(gwgetdata->total_size + 512) / 1024);
 	gtk_list_store_set (GTK_LIST_STORE(model), &iter, TOTALSIZE_COLUMN, size, -1);
 	
 	perc = gwgetdata->total_size==0?0:((gdouble)gwgetdata->cur_size*100)/(gdouble)gwgetdata->total_size ;
@@ -243,29 +240,31 @@ new_download(GwgetData* gwgetdata)
 	
 	g_object_set_data(G_OBJECT(model),gwgetdata->url,gwgetdata);
 	
-	mime = (gchar *)gnome_vfs_mime_type_from_name(gwgetdata->local_filename);
 	theme = gtk_icon_theme_get_default ();
-	icon_name = gnome_icon_lookup (theme, NULL, NULL, NULL, NULL,
-									mime, GNOME_ICON_LOOKUP_FLAGS_NONE, NULL);
+	if (!gwgetdata->recursive) {
+		mime = (gchar *)gnome_vfs_get_mime_type_for_name (gwgetdata->local_filename);
+		gwgetdata->icon_name = gnome_icon_lookup (theme, NULL, NULL, NULL, NULL,
+	 							mime, GNOME_ICON_LOOKUP_FLAGS_NONE, NULL);
+	} else {
+		gwgetdata->icon_name = g_strdup("gtk-refresh");
+	}
 	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &width, &height);
 	width *= 2;
 	height *= 2;
 	
-	icon_info = gtk_icon_theme_lookup_icon (theme, icon_name, width, height);
-	g_free (icon_name);
+	icon_info = gtk_icon_theme_lookup_icon (theme, gwgetdata->icon_name, width, height);
 	if (icon_info == NULL) return;
 	
-	icon_name = g_strdup (gtk_icon_info_get_filename (icon_info));
+	gwgetdata->icon_name = g_strdup (gtk_icon_info_get_filename (icon_info));
 	gtk_icon_info_free (icon_info);
 	
-	pixbuf = gdk_pixbuf_new_from_file_at_size (icon_name, width, height, NULL);
+	pixbuf = gdk_pixbuf_new_from_file_at_size (gwgetdata->icon_name, width, height, NULL);
 	gtk_list_store_set (GTK_LIST_STORE (model),
 				&iter, IMAGE_COLUMN, pixbuf, -1);
 
 	if (pixbuf)
 		g_object_unref (pixbuf);
 	
-	
 }
 
 
@@ -312,6 +311,13 @@ on_boton_pref_clicked(GtkWidget *widget, gpointer data)
 	if (gwget_pref.http_proxy!=NULL) {
 		entry = glade_xml_get_widget(xml_pref,"http_proxy_entry");
 		gtk_entry_set_text(GTK_ENTRY(entry),gwget_pref.http_proxy);
+		checkbutton=glade_xml_get_widget(GLADE_XML(xml_pref),"proxy_uses_auth_radio");
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton),gwget_pref.proxy_uses_auth);
+		entry = glade_xml_get_widget(xml_pref,"proxy_user_entry");
+		gtk_entry_set_text(GTK_ENTRY(entry),gwget_pref.proxy_user);
+		entry = glade_xml_get_widget(xml_pref,"proxy_password_entry");
+		gtk_entry_set_text(GTK_ENTRY(entry),gwget_pref.proxy_password);
+
 	}
 	
 	checkbutton=glade_xml_get_widget(GLADE_XML(xml_pref),"http_proxy_port_spin");
@@ -379,13 +385,13 @@ void
 on_pref_ok_button_clicked(GtkWidget *widget,gpointer data)
 {
 	GtkWidget *save_in = NULL, *ask_each_dl = NULL, *pref_window = NULL,*num_retries=NULL,*resume = NULL, *open_after_dl = NULL;
-	GtkWidget *http_proxy = NULL, *http_proxy_port_spin = NULL;
+	GtkWidget *http_proxy = NULL, *http_proxy_port_spin = NULL, *proxy_user=NULL, *proxy_password=NULL;
 	GtkWidget *no_create_directories = NULL;
 	GtkWidget *follow_relative = NULL;	
 	GtkWidget *convert_links = NULL;
 	GtkWidget *dl_page_requisites = NULL;
 	GtkWidget *max_depth=NULL, *limit_speed_check=NULL, *limit_speed_spin=NULL;
-	GtkWidget *manual_radio=NULL, *direct_radio=NULL, *default_radio=NULL;
+	GtkWidget *manual_radio=NULL, *direct_radio=NULL, *default_radio=NULL, *proxy_uses_auth_radio=NULL;
 	GtkWidget *limit_simultaneousdownloads_check=NULL, *limit_simultaneousdownloads_spin=NULL;
 
 	save_in=glade_xml_get_widget(xml_pref,"save_in_entry");
@@ -398,10 +404,27 @@ on_pref_ok_button_clicked(GtkWidget *widget,gpointer data)
 	gconf_client_set_string(gconf_client,"/apps/gwget2/http_proxy",
 							g_strdup(gtk_entry_get_text(GTK_ENTRY(http_proxy))),NULL);
 	
+	proxy_user=glade_xml_get_widget(xml_pref,"proxy_user");
+	gwget_pref.proxy_user=g_strdup(gtk_entry_get_text(GTK_ENTRY(proxy_user)));
+	gconf_client_set_string(gconf_client,"/apps/gwget2/proxy_user",
+							g_strdup(gtk_entry_get_text(GTK_ENTRY(proxy_user))),NULL);
+							
+	proxy_password=glade_xml_get_widget(xml_pref,"proxy_password");
+	gwget_pref.proxy_password=g_strdup(gtk_entry_get_text(GTK_ENTRY(proxy_password)));
+	gconf_client_set_string(gconf_client,"/apps/gwget2/proxy_password",
+							g_strdup(gtk_entry_get_text(GTK_ENTRY(proxy_password))),NULL);
+	
 	http_proxy_port_spin = glade_xml_get_widget (GLADE_XML(xml_pref), "http_proxy_port_spin");
 	gwget_pref.http_proxy_port = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(http_proxy_port_spin));
 	gconf_client_set_int(gconf_client,"/apps/gwget2/http_proxy_port",
 						  gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(http_proxy_port_spin)),NULL);
+						  
+	proxy_uses_auth_radio=glade_xml_get_widget(xml_pref,"proxy_uses_auth_radio");
+
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (proxy_uses_auth_radio))) {
+		gconf_client_set_bool(gconf_client,"/apps/gwget2/network_mode",TRUE,NULL);
+		gwget_pref.proxy_uses_auth=TRUE;
+	}
 	
 	manual_radio=glade_xml_get_widget(xml_pref,"manual_radio");
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(manual_radio))) {
@@ -450,10 +473,19 @@ on_pref_ok_button_clicked(GtkWidget *widget,gpointer data)
 	
 	/* Limit Speed */
 	limit_speed_check = glade_xml_get_widget (GLADE_XML(xml_pref), "limit_speed_check");
+	limit_speed_spin = glade_xml_get_widget (GLADE_XML(xml_pref), "limit_speed_spin");
+
+	if ( (count_download_in_progress()>0) && 
+	    ((gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(limit_speed_check)) &&
+	    (gwget_pref.max_speed!=gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(limit_speed_spin)))) ||
+	    ( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(limit_speed_check)) && 
+	      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(limit_speed_check))!=gwget_pref.limit_speed)))
+	{
+		inform_limit_speed_change();
+	}	
 	gwget_pref.limit_speed = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(limit_speed_check));
 	gconf_client_set_bool(gconf_client,"/apps/gwget2/limit_speed",
 						  gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(limit_speed_check)),NULL);
-	limit_speed_spin = glade_xml_get_widget (GLADE_XML(xml_pref), "limit_speed_spin");
 	gwget_pref.max_speed = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(limit_speed_spin));
 	gconf_client_set_int(gconf_client,"/apps/gwget2/max_speed",
 						  gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(limit_speed_spin)),NULL);
@@ -584,7 +616,7 @@ on_cancel_download_activate(GtkWidget *widget,gpointer data)
 	if (gwgetdata) 
 	{
 		msg = g_strdup_printf(_("Really cancel current download?\n(URL: %s)"),gwgetdata->url);
-		response = run_dialog(_("Cancel download?"),_(msg));
+		response = run_dialog(_("Cancel download?"),_(msg), _("Cancel"));
 		if (response==GTK_RESPONSE_OK) {
 			gwget_data_stop_download(gwgetdata); 
 			unlink (gwgetdata->local_filename);
@@ -612,19 +644,22 @@ on_remove_completed_activate(GtkWidget *widget, gpointer data)
 	gint length,i;
 	gchar *url;
 	
-	response = run_dialog(_("Remove completed"),_("Really remove completed downloads from the list?"));
-	if (response == GTK_RESPONSE_OK) {
-		length=gtk_tree_model_iter_n_children(GTK_TREE_MODEL(model),NULL);
-		gtk_tree_model_get_iter_root(model,&iter);
-		for (i=0;i<length;i++) {
-			gtk_tree_model_get (model, &iter, URL_COLUMN, &url, -1);
-			gwgetdata=g_object_get_data(G_OBJECT(model),url);
+	if (count_all_downloads()>0) 
+	{
+		response = run_dialog(_("Remove completed"),_("Really remove completed downloads from the list?"), _("Remove"));
+		if (response == GTK_RESPONSE_OK) {
+			length=gtk_tree_model_iter_n_children(GTK_TREE_MODEL(model),NULL);
+			gtk_tree_model_get_iter_root(model,&iter);
+			for (i=0;i<length;i++) {
+				gtk_tree_model_get (model, &iter, URL_COLUMN, &url, -1);
+				gwgetdata=g_object_get_data(G_OBJECT(model),url);
 
-			if (gwgetdata->state==DL_COMPLETED) {
-				gtk_list_store_remove(GTK_LIST_STORE(model),&iter);
-				downloads=g_list_remove(downloads,gwgetdata);
-			} else {
-				gtk_tree_model_iter_next(model,&iter);
+				if (gwgetdata->state==DL_COMPLETED) {
+					gtk_list_store_remove(GTK_LIST_STORE(model),&iter);
+					downloads=g_list_remove(downloads,gwgetdata);
+				} else {
+					gtk_tree_model_iter_next(model,&iter);
+				}
 			}
 		}
 	}
@@ -641,19 +676,22 @@ on_remove_notrunning_activate(GtkWidget *widget, gpointer data)
 	gint length,i;
 	gchar *url;
 	
-	response = run_dialog(_("Remove inactive"),_("Really remove inactive downloads from the list?"));
-	if (response == GTK_RESPONSE_OK) {
-		length=gtk_tree_model_iter_n_children(GTK_TREE_MODEL(model),NULL);
-		gtk_tree_model_get_iter_root(model,&iter);
-		for (i=0;i<length;i++) {
-			gtk_tree_model_get (model, &iter, URL_COLUMN, &url, -1);
-			gwgetdata=g_object_get_data(G_OBJECT(model),url);
+	if (count_all_downloads()>0) 
+	{
+		response = run_dialog(_("Remove inactive"),_("Really remove inactive downloads from the list?"), _("Remove inactive"));
+		if (response == GTK_RESPONSE_OK) {
+			length=gtk_tree_model_iter_n_children(GTK_TREE_MODEL(model),NULL);
+			gtk_tree_model_get_iter_root(model,&iter);
+			for (i=0;i<length;i++) {
+				gtk_tree_model_get (model, &iter, URL_COLUMN, &url, -1);
+				gwgetdata=g_object_get_data(G_OBJECT(model),url);
 			
-			if (gwgetdata->state!=DL_RETRIEVING) {
-				gtk_list_store_remove(GTK_LIST_STORE(model),&iter);
-				downloads=g_list_remove(downloads,gwgetdata);
-			} else {
-				gtk_tree_model_iter_next(model,&iter);
+				if (gwgetdata->state!=DL_RETRIEVING) {
+					gtk_list_store_remove(GTK_LIST_STORE(model),&iter);
+					downloads=g_list_remove(downloads,gwgetdata);
+				} else {
+					gtk_tree_model_iter_next(model,&iter);
+				}
 			}
 		}
 	}
@@ -670,27 +708,30 @@ on_remove_all_activate(GtkWidget *widget, gpointer data)
 	gint length,i;
 	gchar *url;
 	
-	response = run_dialog(_("Remove all"),_("Really remove all downloads from the list?"));
-	if (response == GTK_RESPONSE_OK) {
-		length=gtk_tree_model_iter_n_children(GTK_TREE_MODEL(model),NULL);
-		gtk_tree_model_get_iter_root(model,&iter);
-		for (i=0;i<length;i++) {
-			gtk_tree_model_get (model, &iter, URL_COLUMN, &url, -1);
-			gwgetdata=g_object_get_data(G_OBJECT(model),url);
-			/* If it's running we must stop it */
-			/* because the function that update the info will */
-			/* be continue trying to update the info, so segfault! */
+	if (count_all_downloads()>0) 
+	{
+		response = run_dialog(_("Remove all"),_("Really remove all downloads from the list?"), _("Remove all"));
+		if (response == GTK_RESPONSE_OK) {
+			length=gtk_tree_model_iter_n_children(GTK_TREE_MODEL(model),NULL);
+			gtk_tree_model_get_iter_root(model,&iter);
+			for (i=0;i<length;i++) {
+				gtk_tree_model_get (model, &iter, URL_COLUMN, &url, -1);
+				gwgetdata=g_object_get_data(G_OBJECT(model),url);
+				/* If it's running we must stop it */
+				/* because the function that update the info will */
+				/* be continue trying to update the info, so segfault! */
 
-			if (gwgetdata->state==DL_RETRIEVING) {
-				gwget_data_stop_download(gwgetdata);
-			}
+				if (gwgetdata->state==DL_RETRIEVING) {
+					gwget_data_stop_download(gwgetdata);
+				}
 			
-			gtk_list_store_remove(GTK_LIST_STORE(model),&iter);
-			downloads=g_list_remove(downloads,gwgetdata);
+				gtk_list_store_remove(GTK_LIST_STORE(model),&iter);
+				downloads=g_list_remove(downloads,gwgetdata);
+			}
+			gtk_window_set_title(GTK_WINDOW(glade_xml_get_widget(xml, "main_window")), _("Gwget - Download Manager"));
 		}
-		gtk_window_set_title(GTK_WINDOW(glade_xml_get_widget(xml, "main_window")), _("Gwget - Download Manager"));
 	}
-				
+
 }
 
 void 
@@ -712,6 +753,25 @@ on_view_toolbar_activate(GtkWidget *widget,gpointer data)
 	gconf_client_set_bool(gconf_client,"/apps/gwget2/view_toolbar",state,NULL);
 }
 
+void
+on_view_statusbar_activate(GtkWidget *widget, gpointer data)
+{
+	GtkWidget *statusbar, *menu_item;
+	gboolean state;
+
+	statusbar = glade_xml_get_widget (GLADE_XML(xml), "statusbar");
+	menu_item=glade_xml_get_widget(GLADE_XML(xml),"view_statusbar");
+	state = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menu_item));
+	
+	if (!state) 
+	{
+		gtk_widget_hide(GTK_WIDGET(statusbar));
+	} else {
+		gtk_widget_show(GTK_WIDGET(statusbar));
+	}
+	gconf_client_set_bool(gconf_client,"/apps/gwget2/view_statusbar",state,NULL);
+}
+
 void 
 on_properties_activate(GtkWidget *widget, gpointer data)
 {
@@ -849,33 +909,70 @@ on_limit_simultaneousdownloads_check_toggled (GtkWidget *widget, gpointer data)
 	}
 }
 void 
-on_manual_radio_toggled (GtkWidget *widget, gpointer data) 
+on_manual_radio_toggled (GtkWidget *sender, gpointer data) 
 {
-	GtkWidget *entry;
-	entry = glade_xml_get_widget(xml_pref,"http_proxy_entry");
-	gtk_widget_set_sensitive(GTK_WIDGET(entry),TRUE);
-	entry = glade_xml_get_widget(xml_pref,"http_proxy_port_spin");
-	gtk_widget_set_sensitive(GTK_WIDGET(entry),TRUE);
+	GtkWidget *widget;
+
+	widget = glade_xml_get_widget(xml_pref,"http_proxy_entry");
+	gtk_widget_set_sensitive(GTK_WIDGET (widget), TRUE);
+
+	widget = glade_xml_get_widget(xml_pref, "http_proxy_port_spin");
+	gtk_widget_set_sensitive(GTK_WIDGET (widget), TRUE);
+
+	widget = glade_xml_get_widget(xml_pref, "proxy_uses_auth_radio");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), TRUE);
+	
+	widget = glade_xml_get_widget(xml_pref, "proxy_user");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), TRUE);
+	
+	widget = glade_xml_get_widget(xml_pref, "proxy_password");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), TRUE);
+
 }
 
 void 
-on_direct_radio_toggled (GtkWidget *widget, gpointer data) 
+on_direct_radio_toggled (GtkWidget *sender, gpointer data) 
 {
-	GtkWidget *entry;
-	entry = glade_xml_get_widget(xml_pref,"http_proxy_entry");
-	gtk_widget_set_sensitive(GTK_WIDGET(entry),FALSE);
-	entry = glade_xml_get_widget(xml_pref,"http_proxy_port_spin");
-	gtk_widget_set_sensitive(GTK_WIDGET(entry),FALSE);
+	GtkWidget *widget;
+
+	widget = glade_xml_get_widget(xml_pref,"http_proxy_entry");
+	gtk_widget_set_sensitive(GTK_WIDGET (widget), FALSE);
+	widget = glade_xml_get_widget(xml_pref, "http_proxy_port_spin");
+	gtk_widget_set_sensitive(GTK_WIDGET (widget), FALSE);
+
+	widget = glade_xml_get_widget(xml_pref, "http_proxy_port_spin");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), FALSE);
+	
+	widget = glade_xml_get_widget(xml_pref, "proxy_uses_auth_radio");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), FALSE);
+	
+	widget = glade_xml_get_widget(xml_pref, "proxy_user");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), FALSE);
+	
+	widget = glade_xml_get_widget(xml_pref, "proxy_password");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), FALSE);
+
 }
 
 void 
-on_default_radio_toggled(GtkWidget *widget, gpointer data) 
+on_default_radio_toggled(GtkWidget *sender, gpointer data) 
 {	
-	GtkWidget *entry;
-	entry = glade_xml_get_widget(xml_pref,"http_proxy_entry");
-	gtk_widget_set_sensitive(GTK_WIDGET(entry),FALSE);
-	entry = glade_xml_get_widget(xml_pref,"http_proxy_port_spin");
-	gtk_widget_set_sensitive(GTK_WIDGET(entry),FALSE);
+	GtkWidget *widget;
+
+	widget = glade_xml_get_widget(xml_pref, "http_proxy_entry");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), FALSE);
+	
+	widget = glade_xml_get_widget(xml_pref, "http_proxy_port_spin");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), FALSE);
+	
+	widget = glade_xml_get_widget(xml_pref, "proxy_uses_auth_radio");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), TRUE);
+	
+	widget = glade_xml_get_widget(xml_pref, "proxy_user");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), TRUE);
+	
+	widget = glade_xml_get_widget(xml_pref, "proxy_password");
+	gtk_widget_set_sensitive(GTK_WIDGET(widget), TRUE);
 }
 
 void
@@ -899,9 +996,10 @@ check_download_in_progress(void)
 			inprogress = TRUE;
 			break;
 		}
+		gtk_tree_model_iter_next(model,&iter);
 	}
 
-	if (inprogress==TRUE) {
+	if (inprogress) {
 		set_icon_downloading();
 	} else {
 		set_icon_idle();
@@ -934,7 +1032,7 @@ start_first_waiting_download(void)
 gint count_download_in_progress(void) {
 	GwgetData* gwgetdata;
 	GtkTreeIter iter;
-	gint length, i, number;
+	gint number;
 	gchar *url;
 	gboolean iter_valid;
 
@@ -951,3 +1049,132 @@ gint count_download_in_progress(void) {
 	}
 	return number;
 }
+
+/* Count all downloads */
+gint
+count_all_downloads(void)
+{
+	GtkTreeIter iter;
+	gint number;
+	gboolean iter_valid;
+
+	number=0;
+	for (iter_valid = gtk_tree_model_get_iter_first (model, &iter);iter_valid;iter_valid = gtk_tree_model_iter_next (model, &iter)) {
+		number++;
+	}
+	return number;
+}
+
+
+void
+on_download_menu_activate(void) 
+{
+	gwget_data_set_menus (gwget_data_get_selected());
+}
+
+void
+on_edit_menu_activate(void)
+{
+	if (count_all_downloads()>0) 
+	{
+		 gtk_widget_set_sensitive(glade_xml_get_widget(xml, "remove_item"), TRUE);
+	} else {
+		 gtk_widget_set_sensitive(glade_xml_get_widget(xml, "remove_item"), FALSE);
+	}
+}
+
+static
+void inform_limit_speed_change(void)
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_message_dialog_new (NULL,
+					GTK_DIALOG_MODAL,
+					GTK_MESSAGE_INFO,
+					GTK_BUTTONS_OK,
+					_("New download speed limit will apply only to new or restarted downloads"));
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+}
+
+void
+on_remove_download_activate (GtkWidget *widget, gpointer data)
+{
+	GwgetData *gwgetdata;
+	GtkTreeIter iter;
+	gchar *url;
+	gchar *message;
+	gint response, length, i;
+
+	gwgetdata = gwget_data_get_selected();
+	if (gwgetdata != NULL) {
+	    message = g_strdup_printf (_("Remove %s ?"), gwgetdata->filename);
+		response = run_dialog (message, _("Really remove this download from the list?"), _("Remove download"));
+		if (response == GTK_RESPONSE_OK) {
+			length=gtk_tree_model_iter_n_children(GTK_TREE_MODEL(model),NULL);
+			gtk_tree_model_get_iter_root(model,&iter);
+			for (i=0;i<length;i++) {
+				gtk_tree_model_get (model, &iter, URL_COLUMN, &url, -1);
+				if (gwgetdata==g_object_get_data(G_OBJECT(model),url)) {
+					gtk_list_store_remove(GTK_LIST_STORE(model),&iter);
+					downloads=g_list_remove(downloads,gwgetdata);
+				} else {
+					gtk_tree_model_iter_next(model,&iter);
+				}
+			}
+		}
+	}
+}
+
+void
+on_open_download_activate (GtkWidget *widget, gpointer data)
+{
+	GwgetData *gwgetdata;
+	gchar *uri;
+	GError *err = NULL;
+
+	gwgetdata=gwget_data_get_selected();
+	g_return_if_fail (gwgetdata!=NULL);
+
+	uri = gnome_vfs_make_uri_from_input_with_dirs (gwgetdata->local_filename,
+							GNOME_VFS_MAKE_URI_DIR_CURRENT);
+
+	if (!gnome_url_show (uri, &err)) {
+		run_dialog_error (_("Error opening file"),_("Couldn't open the file"));
+		return;
+	}
+}
+
+void
+on_open_directory_activate (GtkWidget *widget, gpointer data)
+{
+	GwgetData *gwgetdata;
+	gchar *uri;
+	GError *err = NULL;
+
+	gwgetdata=gwget_data_get_selected();
+	g_return_if_fail (gwgetdata!=NULL);
+
+
+	uri = gnome_vfs_make_uri_from_input(gwgetdata->dir);
+
+	if (!gnome_url_show (uri, &err)) {
+		run_dialog_error (_("Error opening file"),_("Couldn't open the folder"));
+		return;
+	}
+}
+
+void
+on_file_menuitem_activate (GtkWidget *widget, gpointer data)
+{
+
+	if (count_all_downloads()==0)
+	{
+		gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_all_menuitem"), FALSE);
+		gtk_widget_set_sensitive(glade_xml_get_widget(xml,"resume_all_menuitem"), FALSE);
+	} else {
+		gtk_widget_set_sensitive(glade_xml_get_widget(xml,"pause_all_menuitem"), TRUE);
+		gtk_widget_set_sensitive(glade_xml_get_widget(xml,"resume_all_menuitem"), TRUE);
+	}
+
+}
